@@ -2,6 +2,12 @@
 #include <fcntl.h>
 #include <iostream>
 
+#include <unistd.h> //The SUN Forte compiler puts F_OK here.
+
+//The SUN Forte compiler needs these for mkfifo:
+#include <sys/types.h>
+#include <sys/stat.h>
+
 int read_fd;
 Glib::RefPtr<Glib::IOChannel> iochannel;
 
@@ -48,7 +54,7 @@ int main(int argc, char *argv[])
     }
   }
  
-  read_fd = open("testfifo", O_RDONLY | O_NONBLOCK);
+  read_fd = open("testfifo", O_RDONLY);
   if (read_fd == -1)
   {
     std::cerr << "error opening fifo" << std::endl;
